﻿using System;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Ink;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using Telerik.Windows.Controls;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Linq;
using Telerik.Windows.Controls.TransitionControl;

namespace RadTransitionControlContentTemplate
{
	public class BusinessCards : ViewModelBase, ISupportInitialize
	{
		public BusinessCards()
		{
			this.SelectOtherSideOfCard = new DelegateCommand(this.SelectDetailedInfo);
			this.SelectNext = new DelegateCommand(this.SelectNextPerson);
			this.SelectPrevious = new DelegateCommand(this.SelectPreviousPerson);

			this.Persons = new ObservableCollection<Person>();
			this.DataTemplates = new ObservableCollection<DataTemplate>();
			this.Transitions = new ObservableCollection<TransitionSet>();
		}

		private void SelectDetailedInfo(object param)
		{
			
			if (this.DataTemplates != null && this.DataTemplates.Count > 1)
			{
				this.SelectDetailedInfoTransition();

				int index = this.DataTemplates.IndexOf(this.SelectedDataTemplate);
				index++;
				if (index >= this.DataTemplates.Count)
				{
					index = 0;
				}
				this.SelectedDataTemplate = this.DataTemplates[index];
			}
		}

		private void SelectNextPerson(object param)
		{
			if (this.Persons != null && this.Persons.Count > 1)
			{
				this.SelectNextForwardTransition();

				int index = this.Persons.IndexOf(this.SelectedPerson);
				index++;
				if (index >= this.Persons.Count)
				{
					index = 0;
				}
				this.SelectedPerson = this.Persons[index];
			}
		}

		private void SelectPreviousPerson(object param)
		{
			if (this.Persons != null && this.Persons.Count > 1)
			{
				this.SelectPreviousBackwardTransition();

				int index = this.Persons.IndexOf(this.SelectedPerson);
				index--;
				if (index < 0)
				{
					index = this.Persons.Count - 1;
				}
				this.SelectedPerson = this.Persons[index];
			}
		}

		private void SelectNextForwardTransition()
		{
			this.CurrentTransition = Transitions[1].ForwardTransition;
		}

		private void SelectPreviousBackwardTransition()
		{
			this.CurrentTransition = Transitions[1].BackwardTransition;
		}

		private void SelectDetailedInfoTransition()
		{
			this.CurrentTransition = Transitions[0].ForwardTransition;
		}

		private TransitionProvider _currentTransition;
		public TransitionProvider CurrentTransition
		{
			get
			{
				return this._currentTransition;
			}
			private set
			{
				if (value != this._currentTransition)
				{
					this._currentTransition = value;
					this.OnPropertyChanged("CurrentTransition");
				}
			}
		}

		private ICommand _selectOtherSideOfCard;
		public ICommand SelectOtherSideOfCard
		{
			get
			{
				return this._selectOtherSideOfCard;
			}
			set
			{
				this._selectOtherSideOfCard = value;
			}
		}

		private ICommand _selectNext;
		public ICommand SelectNext
		{
			get
			{
				return this._selectNext;
			}
			private set
			{
				this._selectNext = value;
			}
		}

		private ICommand _selectPrevious;
		public ICommand SelectPrevious
		{
			get
			{
				return this._selectPrevious;
			}
			set
			{
				this._selectPrevious = value;
			}
		}

		private Person _selectedPerson;
		public Person SelectedPerson
		{
			get
			{
				return this._selectedPerson;
			}
			set
			{
				if ((object)this._selectedPerson != value)
				{
					this._selectedPerson = value;
					this.OnPropertyChanged("SelectedPerson");
				}
			}
		}

		private ObservableCollection<Person> _persons;
		public ObservableCollection<Person> Persons
		{
			get
			{
				return this._persons;
			}
			private set
			{
				if (this._persons != value)
				{
					this._persons = value;
					this.OnPropertyChanged(()=> this.Persons);
				}
			}
		}

		private DataTemplate _selectedDataTemplate;
		public DataTemplate SelectedDataTemplate
		{
			get
			{
				return this._selectedDataTemplate;
			}
			set
			{
				if (this._selectedDataTemplate != value)
				{
					this._selectedDataTemplate = value;
					this.OnPropertyChanged("SelectedDataTemplate");
				}
			}
		}

		private ObservableCollection<DataTemplate> _dataTemplates;
		public ObservableCollection<DataTemplate> DataTemplates
		{
			get
			{
				return this._dataTemplates;
			}
			private set
			{
				if (this._dataTemplates != value)
				{
					this._dataTemplates = value;
					this.OnPropertyChanged("DataTemplates");
				}
			}
		}

		private ObservableCollection<TransitionSet> _transitions;
		public ObservableCollection<TransitionSet> Transitions
		{
			get
			{
				return this._transitions;
			}
			private set
			{

				if (this._transitions != value)
				{
					this._transitions = value;
					this.OnPropertyChanged("Transitions");
				}
			}
		}

		public void BeginInit()
		{
		}

		public void EndInit()
		{
			if ((this.Persons != null && this.Persons.Count > 0))
			{
				this.SelectedPerson = this.Persons.FirstOrDefault();
				this.SelectedDataTemplate = this.DataTemplates.FirstOrDefault();
			}
		}
	}
}
